Authorization
=============

Authorization process varies for "chat creator" and "chat joiner".

For "Chat creator" process includes:

#. creating chat
#. generating "Invitation code"
#. generating "user token"

For "Chat joiner" process includes:

#. verifying "Invitation code"
#. setting chat status as "ready"
#. generating "user token"

More details is in :ref:`diagrams <Diagrams>`.
